======================================================
RECAP (Reproducible Experiment Capture and Provenance)
======================================================

.. image:: https://github.com/NSLS2/recap/actions/workflows/testing.yml/badge.svg
   :target: https://github.com/NSLS2/recap/actions/workflows/testing.yml


.. image:: https://img.shields.io/pypi/v/recap.svg
        :target: https://pypi.python.org/pypi/pyrecap


A scientific framework for Reproducible Experiment Capture, tracking, and metadata management

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) 

Features
--------

* TODO
